@@ -1,6 +1,6 @@
 
 ################################################################
-# This is a generated script based on design: axi_inter_4x128_512_bd
+# This is a generated script based on design: axi_inter_4x64_512_bd
 #
 # Though there are limitations about the generated script,
 # the main purpose of this utility is to make learning
@@ -35,7 +35,7 @@ if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
 ################################################################
 
 # To test this script, run the following commands from Vivado Tcl console:
-# source axi_inter_4x128_512_bd_script.tcl
+# source axi_inter_4x64_512_bd_script.tcl
 
 # If there is no project opened, this script will create a
 # project, but make sure you do not have an existing project
@@ -43,13 +43,13 @@ if { [string first $scripts_vivado_version $current_vivado_version] == -1 } {
 
 set list_projs [get_projects -quiet]
 if { $list_projs eq "" } {
-   create_project project_1 myproj -part xczu28dr-ffve1156-2-e
+   create_project project_1 myproj -part xczu28dr-ffvg1517-1-e
 }
 
 
 # CHANGE DESIGN NAME HERE
 variable design_name
-set design_name axi_inter_4x128_512_bd
+set design_name axi_inter_4x64_512_bd
 
 # If you do not already have an existing IP Integrator design open,
 # you can create a design using the following command:
@@ -109,6 +109,10 @@ if { ${design_name} eq "" } {
 
 }
 
+  # Add USER_COMMENTS on $design_name
+  set_property USER_COMMENTS.comment_0 "Note 1: The ID width of the AXI interconnect (xbar) master changes depending on the axi_interconnect optimization strategy. It will be zero for 'minimize area' and non-zero for 'maximize performance'.
+Note 2: I have explicitly set ID width to 1 on the input ports to match our AXI master and to 4 on the output block to match the DRAM slave." [get_bd_designs $design_name]
+
 common::send_gid_msg -ssname BD::TCL -id 2005 -severity "INFO" "Currently the variable <design_name> is equal to \"$design_name\"."
 
 if { $nRet != 0 } {
@@ -205,7 +209,7 @@ proc create_root_design { parentCell } {
    CONFIG.ARUSER_WIDTH {0} \
    CONFIG.AWUSER_WIDTH {0} \
    CONFIG.BUSER_WIDTH {0} \
-   CONFIG.DATA_WIDTH {128} \
+   CONFIG.DATA_WIDTH {64} \
    CONFIG.FREQ_HZ {350000000} \
    CONFIG.HAS_BRESP {1} \
    CONFIG.HAS_BURST {1} \
@@ -237,7 +241,7 @@ proc create_root_design { parentCell } {
    CONFIG.ARUSER_WIDTH {0} \
    CONFIG.AWUSER_WIDTH {0} \
    CONFIG.BUSER_WIDTH {0} \
-   CONFIG.DATA_WIDTH {128} \
+   CONFIG.DATA_WIDTH {64} \
    CONFIG.FREQ_HZ {350000000} \
    CONFIG.HAS_BRESP {1} \
    CONFIG.HAS_BURST {1} \
@@ -269,7 +273,7 @@ proc create_root_design { parentCell } {
    CONFIG.ARUSER_WIDTH {0} \
    CONFIG.AWUSER_WIDTH {0} \
    CONFIG.BUSER_WIDTH {0} \
-   CONFIG.DATA_WIDTH {128} \
+   CONFIG.DATA_WIDTH {64} \
    CONFIG.FREQ_HZ {350000000} \
    CONFIG.HAS_BRESP {1} \
    CONFIG.HAS_BURST {1} \
@@ -301,7 +305,7 @@ proc create_root_design { parentCell } {
    CONFIG.ARUSER_WIDTH {0} \
    CONFIG.AWUSER_WIDTH {0} \
    CONFIG.BUSER_WIDTH {0} \
-   CONFIG.DATA_WIDTH {128} \
+   CONFIG.DATA_WIDTH {64} \
    CONFIG.FREQ_HZ {350000000} \
    CONFIG.HAS_BRESP {1} \
    CONFIG.HAS_BURST {1} \
@@ -348,7 +352,7 @@ proc create_root_design { parentCell } {
   # Create instance: axi_crossbar_0, and set properties
   set axi_crossbar_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_crossbar:2.1 axi_crossbar_0 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {512} \
+   CONFIG.DATA_WIDTH {256} \
    CONFIG.ID_WIDTH {4} \
    CONFIG.M00_A01_BASE_ADDR {0xffffffffffffffff} \
    CONFIG.M00_A02_BASE_ADDR {0xffffffffffffffff} \
@@ -642,10 +646,9 @@ proc create_root_design { parentCell } {
   # Create instance: axi_dwidth_converter_0, and set properties
   set axi_dwidth_converter_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dwidth_converter:2.1 axi_dwidth_converter_0 ]
   set_property -dict [ list \
-   CONFIG.ACLK_ASYNC {1} \
-   CONFIG.FIFO_MODE {2} \
-   CONFIG.MI_DATA_WIDTH {512} \
-   CONFIG.SI_DATA_WIDTH {128} \
+   CONFIG.FIFO_MODE {1} \
+   CONFIG.MI_DATA_WIDTH {256} \
+   CONFIG.SI_DATA_WIDTH {64} \
    CONFIG.SI_ID_WIDTH {1} \
    CONFIG.SYNCHRONIZATION_STAGES {3} \
  ] $axi_dwidth_converter_0
@@ -653,10 +656,9 @@ proc create_root_design { parentCell } {
   # Create instance: axi_dwidth_converter_1, and set properties
   set axi_dwidth_converter_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dwidth_converter:2.1 axi_dwidth_converter_1 ]
   set_property -dict [ list \
-   CONFIG.ACLK_ASYNC {1} \
-   CONFIG.FIFO_MODE {2} \
-   CONFIG.MI_DATA_WIDTH {512} \
-   CONFIG.SI_DATA_WIDTH {128} \
+   CONFIG.FIFO_MODE {1} \
+   CONFIG.MI_DATA_WIDTH {256} \
+   CONFIG.SI_DATA_WIDTH {64} \
    CONFIG.SI_ID_WIDTH {1} \
    CONFIG.SYNCHRONIZATION_STAGES {3} \
  ] $axi_dwidth_converter_1
@@ -664,10 +666,9 @@ proc create_root_design { parentCell } {
   # Create instance: axi_dwidth_converter_2, and set properties
   set axi_dwidth_converter_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dwidth_converter:2.1 axi_dwidth_converter_2 ]
   set_property -dict [ list \
-   CONFIG.ACLK_ASYNC {1} \
-   CONFIG.FIFO_MODE {2} \
-   CONFIG.MI_DATA_WIDTH {512} \
-   CONFIG.SI_DATA_WIDTH {128} \
+   CONFIG.FIFO_MODE {1} \
+   CONFIG.MI_DATA_WIDTH {256} \
+   CONFIG.SI_DATA_WIDTH {64} \
    CONFIG.SI_ID_WIDTH {1} \
    CONFIG.SYNCHRONIZATION_STAGES {3} \
  ] $axi_dwidth_converter_2
@@ -675,18 +676,27 @@ proc create_root_design { parentCell } {
   # Create instance: axi_dwidth_converter_3, and set properties
   set axi_dwidth_converter_3 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dwidth_converter:2.1 axi_dwidth_converter_3 ]
   set_property -dict [ list \
-   CONFIG.ACLK_ASYNC {1} \
-   CONFIG.FIFO_MODE {2} \
-   CONFIG.MI_DATA_WIDTH {512} \
-   CONFIG.SI_DATA_WIDTH {128} \
+   CONFIG.FIFO_MODE {1} \
+   CONFIG.MI_DATA_WIDTH {256} \
+   CONFIG.SI_DATA_WIDTH {64} \
    CONFIG.SI_ID_WIDTH {1} \
    CONFIG.SYNCHRONIZATION_STAGES {3} \
  ] $axi_dwidth_converter_3
 
+  # Create instance: axi_dwidth_converter_4, and set properties
+  set axi_dwidth_converter_4 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_dwidth_converter:2.1 axi_dwidth_converter_4 ]
+  set_property -dict [ list \
+   CONFIG.ACLK_ASYNC {1} \
+   CONFIG.FIFO_MODE {2} \
+   CONFIG.MI_DATA_WIDTH {512} \
+   CONFIG.SI_DATA_WIDTH {256} \
+   CONFIG.SI_ID_WIDTH {4} \
+   CONFIG.SYNCHRONIZATION_STAGES {2} \
+ ] $axi_dwidth_converter_4
+
   # Create instance: axi_register_slice_0, and set properties
   set axi_register_slice_0 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_0 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {128} \
    CONFIG.ID_WIDTH {1} \
    CONFIG.REG_AR {1} \
    CONFIG.REG_AW {1} \
@@ -696,7 +706,6 @@ proc create_root_design { parentCell } {
   # Create instance: axi_register_slice_1, and set properties
   set axi_register_slice_1 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_1 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {128} \
    CONFIG.ID_WIDTH {1} \
    CONFIG.REG_AR {1} \
    CONFIG.REG_AW {1} \
@@ -706,7 +715,6 @@ proc create_root_design { parentCell } {
   # Create instance: axi_register_slice_2, and set properties
   set axi_register_slice_2 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_2 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {128} \
    CONFIG.ID_WIDTH {1} \
    CONFIG.REG_AR {1} \
    CONFIG.REG_AW {1} \
@@ -716,7 +724,6 @@ proc create_root_design { parentCell } {
   # Create instance: axi_register_slice_3, and set properties
   set axi_register_slice_3 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_3 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {128} \
    CONFIG.ID_WIDTH {1} \
    CONFIG.REG_AR {1} \
    CONFIG.REG_AW {1} \
@@ -726,7 +733,6 @@ proc create_root_design { parentCell } {
   # Create instance: axi_register_slice_4, and set properties
   set axi_register_slice_4 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_4 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {512} \
    CONFIG.ID_WIDTH {1} \
    CONFIG.REG_AR {1} \
    CONFIG.REG_AW {1} \
@@ -736,7 +742,6 @@ proc create_root_design { parentCell } {
   # Create instance: axi_register_slice_5, and set properties
   set axi_register_slice_5 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_5 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {512} \
    CONFIG.ID_WIDTH {1} \
    CONFIG.REG_AR {1} \
    CONFIG.REG_AW {1} \
@@ -746,7 +751,6 @@ proc create_root_design { parentCell } {
   # Create instance: axi_register_slice_6, and set properties
   set axi_register_slice_6 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_6 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {512} \
    CONFIG.ID_WIDTH {1} \
    CONFIG.REG_AR {1} \
    CONFIG.REG_AW {1} \
@@ -756,7 +760,6 @@ proc create_root_design { parentCell } {
   # Create instance: axi_register_slice_7, and set properties
   set axi_register_slice_7 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_7 ]
   set_property -dict [ list \
-   CONFIG.DATA_WIDTH {512} \
    CONFIG.ID_WIDTH {1} \
    CONFIG.REG_AR {1} \
    CONFIG.REG_AW {1} \
@@ -772,16 +775,26 @@ proc create_root_design { parentCell } {
    CONFIG.REG_B {1} \
  ] $axi_register_slice_8
 
+  # Create instance: axi_register_slice_9, and set properties
+  set axi_register_slice_9 [ create_bd_cell -type ip -vlnv xilinx.com:ip:axi_register_slice:2.1 axi_register_slice_9 ]
+  set_property -dict [ list \
+   CONFIG.ID_WIDTH {4} \
+   CONFIG.REG_AR {1} \
+   CONFIG.REG_AW {1} \
+   CONFIG.REG_B {1} \
+ ] $axi_register_slice_9
+
   # Create interface connections
-  connect_bd_intf_net -intf_net S_AXI_0_1 [get_bd_intf_ports S0_AXI] [get_bd_intf_pins axi_register_slice_0/S_AXI]
-  connect_bd_intf_net -intf_net S_AXI_1_1 [get_bd_intf_ports S1_AXI] [get_bd_intf_pins axi_register_slice_1/S_AXI]
-  connect_bd_intf_net -intf_net S_AXI_2_1 [get_bd_intf_ports S2_AXI] [get_bd_intf_pins axi_register_slice_2/S_AXI]
-  connect_bd_intf_net -intf_net S_AXI_3_1 [get_bd_intf_ports S3_AXI] [get_bd_intf_pins axi_register_slice_3/S_AXI]
+  connect_bd_intf_net -intf_net S0_AXI_1 [get_bd_intf_ports S0_AXI] [get_bd_intf_pins axi_register_slice_0/S_AXI]
+  connect_bd_intf_net -intf_net S1_AXI_1 [get_bd_intf_ports S1_AXI] [get_bd_intf_pins axi_register_slice_1/S_AXI]
+  connect_bd_intf_net -intf_net S2_AXI_1 [get_bd_intf_ports S2_AXI] [get_bd_intf_pins axi_register_slice_2/S_AXI]
+  connect_bd_intf_net -intf_net S3_AXI_1 [get_bd_intf_ports S3_AXI] [get_bd_intf_pins axi_register_slice_3/S_AXI]
   connect_bd_intf_net -intf_net axi_crossbar_0_M00_AXI [get_bd_intf_pins axi_crossbar_0/M00_AXI] [get_bd_intf_pins axi_register_slice_8/S_AXI]
   connect_bd_intf_net -intf_net axi_dwidth_converter_0_M_AXI [get_bd_intf_pins axi_dwidth_converter_0/M_AXI] [get_bd_intf_pins axi_register_slice_4/S_AXI]
   connect_bd_intf_net -intf_net axi_dwidth_converter_1_M_AXI [get_bd_intf_pins axi_dwidth_converter_1/M_AXI] [get_bd_intf_pins axi_register_slice_5/S_AXI]
-  connect_bd_intf_net -intf_net axi_dwidth_converter_2_M_AXI [get_bd_intf_pins axi_dwidth_converter_2/M_AXI] [get_bd_intf_pins axi_register_slice_6/S_AXI]
+  connect_bd_intf_net -intf_net axi_dwidth_converter_2_M_AXI1 [get_bd_intf_pins axi_dwidth_converter_2/M_AXI] [get_bd_intf_pins axi_register_slice_6/S_AXI]
   connect_bd_intf_net -intf_net axi_dwidth_converter_3_M_AXI [get_bd_intf_pins axi_dwidth_converter_3/M_AXI] [get_bd_intf_pins axi_register_slice_7/S_AXI]
+  connect_bd_intf_net -intf_net axi_dwidth_converter_4_M_AXI [get_bd_intf_pins axi_dwidth_converter_4/M_AXI] [get_bd_intf_pins axi_register_slice_9/S_AXI]
   connect_bd_intf_net -intf_net axi_register_slice_0_M_AXI [get_bd_intf_pins axi_dwidth_converter_0/S_AXI] [get_bd_intf_pins axi_register_slice_0/M_AXI]
   connect_bd_intf_net -intf_net axi_register_slice_1_M_AXI [get_bd_intf_pins axi_dwidth_converter_1/S_AXI] [get_bd_intf_pins axi_register_slice_1/M_AXI]
   connect_bd_intf_net -intf_net axi_register_slice_2_M_AXI [get_bd_intf_pins axi_dwidth_converter_2/S_AXI] [get_bd_intf_pins axi_register_slice_2/M_AXI]
@@ -790,14 +803,15 @@ proc create_root_design { parentCell } {
   connect_bd_intf_net -intf_net axi_register_slice_5_M_AXI [get_bd_intf_pins axi_crossbar_0/S01_AXI] [get_bd_intf_pins axi_register_slice_5/M_AXI]
   connect_bd_intf_net -intf_net axi_register_slice_6_M_AXI [get_bd_intf_pins axi_crossbar_0/S02_AXI] [get_bd_intf_pins axi_register_slice_6/M_AXI]
   connect_bd_intf_net -intf_net axi_register_slice_7_M_AXI [get_bd_intf_pins axi_crossbar_0/S03_AXI] [get_bd_intf_pins axi_register_slice_7/M_AXI]
-  connect_bd_intf_net -intf_net axi_register_slice_8_M_AXI [get_bd_intf_ports M0_AXI] [get_bd_intf_pins axi_register_slice_8/M_AXI]
+  connect_bd_intf_net -intf_net axi_register_slice_8_M_AXI [get_bd_intf_pins axi_dwidth_converter_4/S_AXI] [get_bd_intf_pins axi_register_slice_8/M_AXI]
+  connect_bd_intf_net -intf_net axi_register_slice_9_M_AXI [get_bd_intf_ports M0_AXI] [get_bd_intf_pins axi_register_slice_9/M_AXI]
 
   # Create port connections
-  connect_bd_net -net S0_AXI_ACLK [get_bd_ports S0_AXI_ACLK] [get_bd_pins axi_dwidth_converter_0/s_axi_aclk] [get_bd_pins axi_dwidth_converter_1/s_axi_aclk] [get_bd_pins axi_dwidth_converter_2/s_axi_aclk] [get_bd_pins axi_dwidth_converter_3/s_axi_aclk] [get_bd_pins axi_register_slice_0/aclk] [get_bd_pins axi_register_slice_1/aclk] [get_bd_pins axi_register_slice_2/aclk] [get_bd_pins axi_register_slice_3/aclk]
-  connect_bd_net -net S0_AXI_ARESETN_1 [get_bd_ports S0_AXI_ARESETN] [get_bd_pins axi_dwidth_converter_0/s_axi_aresetn] [get_bd_pins axi_dwidth_converter_1/s_axi_aresetn] [get_bd_pins axi_dwidth_converter_2/s_axi_aresetn] [get_bd_pins axi_dwidth_converter_3/s_axi_aresetn] [get_bd_pins axi_register_slice_0/aresetn] [get_bd_pins axi_register_slice_1/aresetn] [get_bd_pins axi_register_slice_2/aresetn] [get_bd_pins axi_register_slice_3/aresetn]
-  connect_bd_net -net M0_AXI_ACLK_1 [get_bd_ports M0_AXI_ACLK] [get_bd_pins axi_crossbar_0/aclk] [get_bd_pins axi_dwidth_converter_0/m_axi_aclk] [get_bd_pins axi_dwidth_converter_1/m_axi_aclk] [get_bd_pins axi_dwidth_converter_2/m_axi_aclk] [get_bd_pins axi_dwidth_converter_3/m_axi_aclk] [get_bd_pins axi_register_slice_4/aclk] [get_bd_pins axi_register_slice_5/aclk] [get_bd_pins axi_register_slice_6/aclk] [get_bd_pins axi_register_slice_7/aclk] [get_bd_pins axi_register_slice_8/aclk]
-  connect_bd_net -net M0_AXI_ARESETN_1 [get_bd_ports M0_AXI_ARESETN] [get_bd_pins axi_crossbar_0/aresetn] [get_bd_pins axi_dwidth_converter_0/m_axi_aresetn] [get_bd_pins axi_dwidth_converter_1/m_axi_aresetn] [get_bd_pins axi_dwidth_converter_2/m_axi_aresetn] [get_bd_pins axi_dwidth_converter_3/m_axi_aresetn] [get_bd_pins axi_register_slice_4/aresetn] [get_bd_pins axi_register_slice_5/aresetn] [get_bd_pins axi_register_slice_6/aresetn] [get_bd_pins axi_register_slice_8/aresetn]
-  
+  connect_bd_net -net M0_AXI_ACLK_1 [get_bd_ports M0_AXI_ACLK] [get_bd_pins axi_dwidth_converter_4/m_axi_aclk] [get_bd_pins axi_register_slice_9/aclk]
+  connect_bd_net -net M0_AXI_ARESETN_1 [get_bd_ports M0_AXI_ARESETN] [get_bd_pins axi_dwidth_converter_4/m_axi_aresetn] [get_bd_pins axi_register_slice_9/aresetn]
+  connect_bd_net -net S0_AXI_ACLK_1 [get_bd_ports S0_AXI_ACLK] [get_bd_pins axi_crossbar_0/aclk] [get_bd_pins axi_dwidth_converter_0/s_axi_aclk] [get_bd_pins axi_dwidth_converter_1/s_axi_aclk] [get_bd_pins axi_dwidth_converter_2/s_axi_aclk] [get_bd_pins axi_dwidth_converter_3/s_axi_aclk] [get_bd_pins axi_dwidth_converter_4/s_axi_aclk] [get_bd_pins axi_register_slice_0/aclk] [get_bd_pins axi_register_slice_1/aclk] [get_bd_pins axi_register_slice_2/aclk] [get_bd_pins axi_register_slice_3/aclk] [get_bd_pins axi_register_slice_4/aclk] [get_bd_pins axi_register_slice_5/aclk] [get_bd_pins axi_register_slice_6/aclk] [get_bd_pins axi_register_slice_7/aclk] [get_bd_pins axi_register_slice_8/aclk]
+  connect_bd_net -net S0_AXI_ARESETN_1 [get_bd_ports S0_AXI_ARESETN] [get_bd_pins axi_crossbar_0/aresetn] [get_bd_pins axi_dwidth_converter_0/s_axi_aresetn] [get_bd_pins axi_dwidth_converter_1/s_axi_aresetn] [get_bd_pins axi_dwidth_converter_2/s_axi_aresetn] [get_bd_pins axi_dwidth_converter_3/s_axi_aresetn] [get_bd_pins axi_dwidth_converter_4/s_axi_aresetn] [get_bd_pins axi_register_slice_0/aresetn] [get_bd_pins axi_register_slice_1/aresetn] [get_bd_pins axi_register_slice_2/aresetn] [get_bd_pins axi_register_slice_3/aresetn] [get_bd_pins axi_register_slice_4/aresetn] [get_bd_pins axi_register_slice_5/aresetn] [get_bd_pins axi_register_slice_6/aresetn] [get_bd_pins axi_register_slice_7/aresetn] [get_bd_pins axi_register_slice_8/aresetn]
+
   # Create address segments
   assign_bd_address -offset 0x00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces S0_AXI] [get_bd_addr_segs M0_AXI/Reg] -force
   assign_bd_address -offset 0x00000000 -range 0x000100000000 -target_address_space [get_bd_addr_spaces S1_AXI] [get_bd_addr_segs M0_AXI/Reg] -force
