@@ -3,7 +3,7 @@
 #ifndef ASYNC_WRITER_H_HQIRH28I
 #define ASYNC_WRITER_H_HQIRH28I
 
-#include <boost/asio.hpp>
+#include <uhdlib/asio.hpp>
 #include "rpc/msgpack.hpp"
 #include <condition_variable>
 #include <deque>
