@@ -17,6 +17,7 @@ void export_fft_block_control(py::module& m)
         .value("NORMAL", fft_shift::NORMAL)
         .value("REVERSE", fft_shift::REVERSE)
         .value("NATURAL", fft_shift::NATURAL)
+        .value("BIT_REVERSE", fft_shift::BIT_REVERSE)
         .export_values();
 
     py::enum_<fft_direction>(m, "fft_direction")
@@ -44,6 +45,9 @@ void export_fft_block_control(py::module& m)
         .def("get_scaling", &fft_block_control::get_scaling)
         .def("set_length", &fft_block_control::set_length)
         .def("get_length", &fft_block_control::get_length)
+        .def("set_bypass_mode", &fft_block_control::set_bypass_mode)
+        .def("get_bypass_mode", &fft_block_control::get_bypass_mode)
+        .def("get_nipc", &fft_block_control::get_nipc)
         .def("get_max_length", &fft_block_control::get_max_length)
         .def("get_max_cp_length", &fft_block_control::get_max_cp_length)
         .def("get_max_cp_removal_list_length",
