@@ -10,6 +10,7 @@
 #include "../stream_python.hpp"
 #include <uhd/features/discoverable_feature.hpp>
 #include <uhd/features/gpio_power_iface.hpp>
+#include <uhd/features/gps_iface.hpp>
 #include <uhd/rfnoc/block_id.hpp>
 #include <uhd/rfnoc/filter_node.hpp>
 #include <uhd/rfnoc/graph_edge.hpp>
@@ -197,7 +198,7 @@ void export_rfnoc(py::module& m)
             py::arg("streamer"),
             py::arg("strm_port"),
             py::arg("dst_blk"),
-            py::arg("dst_blk"),
+            py::arg("dst_port"),
             py::arg("adapter_id") = uhd::transport::NULL_ADAPTER_ID)
         .def("connect",
             py::overload_cast<const block_id_t&,
@@ -206,7 +207,7 @@ void export_rfnoc(py::module& m)
                 size_t,
                 uhd::transport::adapter_id_t>(&rfnoc_graph::connect),
             py::arg("src_blk"),
-            py::arg("src_blk"),
+            py::arg("src_port"),
             py::arg("streamer"),
             py::arg("strm_port"),
             py::arg("adapter_id") = uhd::transport::NULL_ADAPTER_ID)
@@ -244,6 +245,11 @@ void export_rfnoc(py::module& m)
         .def("get_external_power_status",
             &uhd::features::gpio_power_iface::get_external_power_status);
 
+    py::class_<uhd::features::gps_iface>(m, "gps")
+        .def("get_sensor", &uhd::features::gps_iface::get_sensor)
+        .def("get_sensors", &uhd::features::gps_iface::get_sensors)
+        .def("send_cmd", &uhd::features::gps_iface::send_cmd);
+
     py::class_<detail::filter_node>(m, "filter_node")
         .def("get_rx_filter_names", &detail::filter_node::get_rx_filter_names)
         .def("get_rx_filter", &detail::filter_node::get_rx_filter)
@@ -289,6 +295,12 @@ void export_rfnoc(py::module& m)
             [](mb_controller& self) {
                 return &self.get_feature<uhd::features::gpio_power_iface>();
             },
+            py::return_value_policy::reference_internal)
+        .def(
+            "get_gps_iface",
+            [](mb_controller& self) {
+                return &self.get_feature<uhd::features::gps_iface>();
+            },
             py::return_value_policy::reference_internal);
 
     py::class_<timekeeper, PyTimekeeper, timekeeper::sptr>(m, "timekeeper")
