@@ -5,7 +5,7 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#include <uhd/transport/nirio/niriok_proxy_impl_v1.h>
+#include <uhdlib/transport/nirio/niriok_proxy_impl_v1.h>
 #include <cstring>
 
 // "push" and "pop" introduced in GCC 4.6; works with all clang
