@@ -16,9 +16,6 @@ static constexpr char MPM_CATCHALL_DEVICE_TYPE[] = "mpm";
 // List all MPM devices here by their 'type' key. Note: Do not use these values
 // to make decisions. This vector is for filtering purposes.
 static const std::vector<std::string> MPM_DEVICE_TYPES = {
-    MPM_CATCHALL_DEVICE_TYPE,
-    "n3xx",
-    "e3xx",
-    "x4xx"};
+    MPM_CATCHALL_DEVICE_TYPE, "n3xx", "e3xx", "x4xx"};
 
 #endif /* INCLUDED_MPMD_DEVICES_HPP */
