@@ -16,8 +16,8 @@
 #include <uhd/utils/platform.hpp>
 #include <uhd/utils/safe_call.hpp>
 #include <uhd/utils/tasks.hpp>
+#include <uhdlib/asio.hpp> //used for htonl and ntohl
 #include <uhdlib/utils/paths.hpp>
-#include <boost/asio.hpp> //used for htonl and ntohl
 #include <boost/assign/list_of.hpp>
 #include <boost/filesystem.hpp>
 #include <boost/format.hpp>
@@ -80,7 +80,7 @@ public:
 
     ~usrp2_iface_impl(void) override
     {
-        UHD_SAFE_CALL(this->lock_device(false);)
+        UHD_SAFE_CALL(this->lock_device(false));
     }
 
     /***********************************************************************
