@@ -11,6 +11,7 @@
 #include "ad5623_regs.hpp" //aux dac
 #include "ad7922_regs.hpp" //aux adc
 #include "x300_clock_ctrl.hpp"
+#include <uhd/config.h>
 #include <uhd/rfnoc/register_iface.hpp>
 #include <uhd/types/dict.hpp>
 #include <uhd/usrp/dboard_iface.hpp>
@@ -18,6 +19,7 @@
 #include <uhdlib/usrp/cores/i2c_core_100_wb32.hpp>
 #include <uhdlib/usrp/cores/rx_frontend_core_3000.hpp>
 #include <uhdlib/usrp/cores/spi_core_3000.hpp>
+#include <uhdlib/usrp/cores/tx_frontend_core_200.hpp>
 
 
 struct x300_dboard_iface_config_t
@@ -92,13 +94,13 @@ public:
         const std::string& name,
         const uhd::usrp::fe_connection_t& fe_conn) override;
 
-    // X300 can set the FE connection on the RX side
-    bool has_set_fe_connection(const unit_t unit) override
+    bool has_set_fe_connection(UHD_UNUSED(const unit_t unit)) override
     {
-        return unit == UNIT_RX;
+        return true;
     }
 
     void add_rx_fe(const std::string& fe_name, rx_frontend_core_3000::sptr fe_core);
+    void add_tx_fe(const std::string& fe_name, tx_frontend_core_200::sptr fe_core);
 
     void define_custom_register_space(const uint32_t start_addr,
         const uint32_t length,
@@ -110,6 +112,7 @@ private:
     uhd::dict<unit_t, ad5623_regs_t> _dac_regs;
     uhd::dict<unit_t, double> _clock_rates;
     uhd::dict<std::string, rx_frontend_core_3000::sptr> _rx_fes;
+    uhd::dict<std::string, tx_frontend_core_200::sptr> _tx_fes;
     void _write_aux_dac(unit_t);
 };
 
