@@ -14,7 +14,7 @@
 #include <uhd/usrp/mboard_eeprom.hpp>
 #include <uhd/usrp_clock/octoclock_eeprom.hpp>
 #include <uhd/utils/byteswap.hpp>
-#include <boost/asio.hpp>
+#include <uhdlib/asio.hpp>
 
 typedef boost::asio::ip::address_v4 ip_v4;
 
