@@ -8,16 +8,6 @@
 #include <uhd/utils/math.hpp>
 #include <boost/test/unit_test.hpp>
 
-BOOST_AUTO_TEST_CASE(test_lcm)
-{
-    BOOST_CHECK_EQUAL(uhd::math::lcm<int>(2, 3), 6);
-}
-
-BOOST_AUTO_TEST_CASE(test_gcd)
-{
-    BOOST_CHECK_EQUAL(uhd::math::gcd<int>(6, 15), 3);
-}
-
 BOOST_AUTO_TEST_CASE(test_sign)
 {
     BOOST_CHECK_EQUAL(uhd::math::sign(2.3), +1);
