@@ -4,13 +4,13 @@
 // SPDX-License-Identifier: GPL-3.0-or-later
 //
 
-#include "../rfnoc_graph_mock_nodes.hpp"
 #include "x4xx_radio_mock.hpp"
 #include "x4xx_zbx_mpm_mock.hpp"
+#include <uhd/rfnoc/detail/graph.hpp>
 #include <uhd/rfnoc/mock_block.hpp>
+#include <uhd/rfnoc/mock_nodes.hpp>
 #include <uhd/utils/log.hpp>
 #include <uhd/utils/math.hpp>
-#include <uhdlib/rfnoc/graph.hpp>
 #include <boost/test/unit_test.hpp>
 #include <cstddef>
 #include <iostream>
@@ -18,6 +18,7 @@
 
 using namespace uhd;
 using namespace uhd::rfnoc;
+using namespace uhd::rfnoc::test;
 using namespace std::chrono_literals;
 using namespace uhd::usrp::zbx;
 using namespace uhd::experts;
@@ -31,15 +32,15 @@ BOOST_FIXTURE_TEST_CASE(x400_radio_test_graph, x400_radio_fixture)
 {
     detail::graph_t graph{};
     detail::graph_t::graph_edge_t edge_port_info0;
-    edge_port_info0.src_port                    = 0;
-    edge_port_info0.dst_port                    = 0;
-    edge_port_info0.property_propagation_active = true;
-    edge_port_info0.edge                        = detail::graph_t::graph_edge_t::DYNAMIC;
+    edge_port_info0.src_port        = 0;
+    edge_port_info0.dst_port        = 0;
+    edge_port_info0.is_forward_edge = true;
+    edge_port_info0.edge            = detail::graph_t::graph_edge_t::DYNAMIC;
     detail::graph_t::graph_edge_t edge_port_info1;
-    edge_port_info1.src_port                    = 1;
-    edge_port_info1.dst_port                    = 1;
-    edge_port_info1.property_propagation_active = true;
-    edge_port_info1.edge                        = detail::graph_t::graph_edge_t::DYNAMIC;
+    edge_port_info1.src_port        = 1;
+    edge_port_info1.dst_port        = 1;
+    edge_port_info1.is_forward_edge = true;
+    edge_port_info1.edge            = detail::graph_t::graph_edge_t::DYNAMIC;
 
     mock_radio_node_t mock_radio_block{0};
     mock_terminator_t mock_sink_term(2, {}, "MOCK_SINK");
@@ -69,21 +70,21 @@ BOOST_FIXTURE_TEST_CASE(x400_radio_test_graph, x400_radio_fixture)
 /******************************************************************************
  * RFNoC atomic item size property test
  *
- * This test case ensures that the radio block propagates atomic item size correct
+ * This test case ensures that the radio block propagates atomic item size correctly
  *****************************************************************************/
 BOOST_FIXTURE_TEST_CASE(x400_radio_test_prop_prop, x400_radio_fixture)
 {
     detail::graph_t graph{};
     detail::graph_t::graph_edge_t edge_port_info0;
-    edge_port_info0.src_port                    = 0;
-    edge_port_info0.dst_port                    = 0;
-    edge_port_info0.property_propagation_active = true;
-    edge_port_info0.edge                        = detail::graph_t::graph_edge_t::DYNAMIC;
+    edge_port_info0.src_port        = 0;
+    edge_port_info0.dst_port        = 0;
+    edge_port_info0.is_forward_edge = true;
+    edge_port_info0.edge            = detail::graph_t::graph_edge_t::DYNAMIC;
     detail::graph_t::graph_edge_t edge_port_info1;
-    edge_port_info1.src_port                    = 1;
-    edge_port_info1.dst_port                    = 1;
-    edge_port_info1.property_propagation_active = true;
-    edge_port_info1.edge                        = detail::graph_t::graph_edge_t::DYNAMIC;
+    edge_port_info1.src_port        = 1;
+    edge_port_info1.dst_port        = 1;
+    edge_port_info1.is_forward_edge = true;
+    edge_port_info1.edge            = detail::graph_t::graph_edge_t::DYNAMIC;
 
     mock_terminator_t mock_sink_term(2, {}, "MOCK_SINK");
     mock_terminator_t mock_source_term(2, {}, "MOCK_SOURCE");
@@ -166,20 +167,36 @@ BOOST_FIXTURE_TEST_CASE(x400_radio_test_prop_prop, x400_radio_fixture)
     BOOST_CHECK_EQUAL(mock_sink_term.get_edge_property<size_t>(
                           "atomic_item_size", {res_source_info::INPUT_EDGE, 0}),
         28);
+    BOOST_CHECK_EQUAL(test_radio->get_property<int>("spp", 0) % 7, 0);
 
     mock_sink_term.set_edge_property<size_t>(
         "atomic_item_size", 22, {res_source_info::INPUT_EDGE, 1});
     BOOST_CHECK_EQUAL(mock_sink_term.get_edge_property<size_t>(
                           "atomic_item_size", {res_source_info::INPUT_EDGE, 1}),
         44);
+    BOOST_CHECK_EQUAL(test_radio->get_property<int>("spp", 1) % 11, 0);
 
     mock_sink_term.set_edge_property<size_t>(
         "mtu", 179, {res_source_info::INPUT_EDGE, 0});
     mock_sink_term.set_edge_property<size_t>(
-        "atomic_item_size", 47, {res_source_info::INPUT_EDGE, 0});
+        "atomic_item_size", 46, {res_source_info::INPUT_EDGE, 0});
     BOOST_CHECK_EQUAL(mock_sink_term.get_edge_property<size_t>(
                           "atomic_item_size", {res_source_info::INPUT_EDGE, 0}),
-        176);
+        92);
+    BOOST_CHECK_EQUAL(test_radio->get_property<int>("spp", 0), 23);
+
+    test_radio->set_property<int>("spp", 3, 0);
+    BOOST_CHECK_EQUAL(test_radio->get_property<int>("spp", 0), 23);
+    test_radio->set_property<int>("spp", 24, 0);
+    BOOST_CHECK_EQUAL(test_radio->get_property<int>("spp", 0), 23);
+
+    // If we go higher, then there's no valid spp value that is both smaller than
+    // MTU *and* a multiple of AIS
+    UHD_LOG_INFO("TEST", "Expecting ERROR here VVV");
+    BOOST_REQUIRE_THROW(mock_sink_term.set_edge_property<size_t>(
+                            "atomic_item_size", 47, {res_source_info::INPUT_EDGE, 0}),
+        uhd::resolve_error);
+    UHD_LOG_INFO("TEST", "Expecting ERROR here ^^^");
 }
 
 BOOST_FIXTURE_TEST_CASE(zbx_api_freq_tx_test, x400_radio_fixture)
@@ -596,15 +613,15 @@ BOOST_FIXTURE_TEST_CASE(zbx_custom_tx_tune_table_test, x400_radio_fixture)
     // that band is 10MHz lower (chosen arbitrarily)
     // Turn clang-formatting off so it doesn't compress these tables into a mess.
     // clang-format off
-    static const std::vector<tune_map_item_t> alternate_tx_tune_map = {
-    //  | min_band_freq | max_band_freq | rf_fir | if1_fir | if2_fir | mix1 m, n | mix2 m, n | if1_freq_min | if1_freq_max | if2_freq_min | if2_freq_max |
-        {   4030e6,         4500e6,          0,       1,        1,       0,  0,     -1,  1,            0,             0,        1050e6,        1050e6    },
+    static const std::vector<zbx_tune_map_item_t> alternate_tx_tune_map = {
+    //  | min_band_freq | max_band_freq | rf_fir | if1_fir | if2_fir | lo1_inj_side | lo2_inj_side | if1_freq_min | if1_freq_max | if2_freq_min | if2_freq_max |
+        {   4030e6,         4500e6,          0,       1,        1,      NONE,               HIGH,          0,             0,        1050e6,        1050e6    },
     };
 
     // Turn clang-format back on just for posterity
     // clang-format on
 
-    tree->access<std::vector<uhd::usrp::zbx::tune_map_item_t>>(
+    tree->access<std::vector<uhd::usrp::zbx::zbx_tune_map_item_t>>(
             "dboard/tx_frontends/0/tune_table")
         .set(alternate_tx_tune_map);
 
@@ -626,15 +643,15 @@ BOOST_FIXTURE_TEST_CASE(zbx_custom_rx_tune_table_test, x400_radio_fixture)
     // that band is 10MHz lower (chosen arbitrarily)
     // Turn clang-formatting off so it doesn't compress these tables into a mess.
     // clang-format off
-    static const std::vector<tune_map_item_t> alternate_rx_tune_map = {
-    //  | min_band_freq | max_band_freq | rf_fir | if1_fir | if2_fir | mix1 m, n | mix2 m, n | if1_freq_min | if1_freq_max | if2_freq_min | if2_freq_max |
-        {   4200e6,         4500e6,          0,       2,        2,       0,  0,     -1,  1,            0,             0,        1840e6,        1840e6    },
+    static const std::vector<zbx_tune_map_item_t> alternate_rx_tune_map = {
+    //  | min_band_freq | max_band_freq | rf_fir | if1_fir | if2_fir | lo1_inj_side | lo2_inj_side | if1_freq_min | if1_freq_max | if2_freq_min | if2_freq_max |
+        {   4200e6,         4500e6,          0,       2,        2,     NONE,                 HIGH,          0,             0,        1840e6,        1840e6    },
     };
 
     // Turn clang-format back on just for posterity
     // clang-format on
 
-    tree->access<std::vector<uhd::usrp::zbx::tune_map_item_t>>(
+    tree->access<std::vector<uhd::usrp::zbx::zbx_tune_map_item_t>>(
             "dboard/rx_frontends/0/tune_table")
         .set(alternate_rx_tune_map);
 
@@ -756,6 +773,14 @@ BOOST_FIXTURE_TEST_CASE(zbx_phase_sync_test, x400_radio_fixture)
     constexpr uint32_t nco_sync_addr = 0x88000;
     constexpr uint32_t gearbox_addr  = 0x88004;
     auto& regs                       = reg_iface->read_memory;
+    // Set reset complete bit
+    regs[nco_sync_addr] = 1 << 1;
+    constexpr uint32_t nco_sync_val =
+        (11 & 0xFF) << uhd::rfnoc::x400::rfdc_control::regmap::SYSREF_WAIT_LSB
+        | 1 << uhd::rfnoc::x400::rfdc_control::regmap::WRITE_SYSREF_WAIT
+        | 1 << uhd::rfnoc::x400::rfdc_control::regmap::NCO_RESET_DONE_MSB
+        | 1 << uhd::rfnoc::x400::rfdc_control::regmap::NCO_RESET_START_MSB;
+
     UHD_LOG_INFO("TEST", "Setting 1 GHz defaults...");
     // Confirm default
     test_radio->set_rx_frequency(1e9, 0);
@@ -770,11 +795,11 @@ BOOST_FIXTURE_TEST_CASE(zbx_phase_sync_test, x400_radio_fixture)
     test_radio->set_rx_frequency(2.3e9, 0);
     // Check we synced RX LOs chan 0 and RX NCO chan 0, and ADC gearboxes
     BOOST_CHECK_EQUAL(regs[lo_sync_addr], 0b11 << 4);
-    BOOST_CHECK_EQUAL(regs[nco_sync_addr], 1);
+    BOOST_CHECK_EQUAL(regs[nco_sync_addr], nco_sync_val);
     BOOST_CHECK_EQUAL(regs[gearbox_addr], 1);
     // Reset strobes
     regs[lo_sync_addr]  = 0;
-    regs[nco_sync_addr] = 0;
+    regs[nco_sync_addr] = 1 << 1; // Set reset complete bit
     regs[gearbox_addr]  = 0;
     UHD_LOG_INFO("TEST", "Enabling time stamp chan 1...");
     test_radio->set_command_time(uhd::time_spec_t(2.0), 1);
@@ -783,28 +808,28 @@ BOOST_FIXTURE_TEST_CASE(zbx_phase_sync_test, x400_radio_fixture)
     // Check we synced RX LOs chan 1 and RX NCO chan 1. ADC gearbox only gets
     // reset once, and should be left untouched.
     BOOST_CHECK_EQUAL(regs[lo_sync_addr], 0b11 << 6);
-    BOOST_CHECK_EQUAL(regs[nco_sync_addr], 1);
+    BOOST_CHECK_EQUAL(regs[nco_sync_addr], nco_sync_val);
     BOOST_CHECK_EQUAL(regs[gearbox_addr], 0);
     // Reset strobes
     regs[lo_sync_addr]  = 0;
-    regs[nco_sync_addr] = 0;
+    regs[nco_sync_addr] = 1 << 1; // Set reset complete bit
     regs[gearbox_addr]  = 0;
     UHD_LOG_INFO("TEST", "Setting TX chan 0 to 2.3 GHz...");
     test_radio->set_tx_frequency(2.3e9, 0);
     // Check we synced TX LOs chan 0 and TX NCO chan 0, and DAC gearboxes
     BOOST_CHECK_EQUAL(regs[lo_sync_addr], 0x3 << 0);
-    BOOST_CHECK_EQUAL(regs[nco_sync_addr], 1);
+    BOOST_CHECK_EQUAL(regs[nco_sync_addr], nco_sync_val);
     BOOST_CHECK_EQUAL(regs[gearbox_addr], 1 << 1);
     // Reset strobe
     regs[lo_sync_addr]  = 0;
-    regs[nco_sync_addr] = 0;
+    regs[nco_sync_addr] = 1 << 1; // Set reset complete bit
     regs[gearbox_addr]  = 0;
     UHD_LOG_INFO("TEST", "Setting TX chan 1 to 2.3 GHz...");
     test_radio->set_tx_frequency(2.3e9, 1);
     // Check we synced TX LOs chan 1 and TX NCO chan 1. DAC gearbox only gets
     // reset once, and should be left untouched.
     BOOST_CHECK_EQUAL(regs[lo_sync_addr], 0xC << 0);
-    BOOST_CHECK_EQUAL(regs[nco_sync_addr], 1);
+    BOOST_CHECK_EQUAL(regs[nco_sync_addr], nco_sync_val);
     BOOST_CHECK_EQUAL(regs[gearbox_addr], 0);
     // Reset strobe
     regs[lo_sync_addr]  = 0;
