@@ -8,12 +8,36 @@ import argparse
 import hashlib
 import logging
 import os
-import re
 import sys
 
+from uhd import get_pkg_data_path
 from uhd.rfnoc_utils import image_builder, log as rfnoc_log
 
 
+def get_valid_targets():
+    """Get valid targets (--target parameter)."""
+    target_fpga_map = {
+        "E310_SG1": ["", "IDLE"],
+        "E310_SG3": ["", "IDLE"],
+        "E320": ["1G", "XG", "AA"],
+        "N310": ["WX", "HG", "XG", "HA", "XA", "AA"],
+        "N300": ["WX", "HG", "XG", "HA", "XA", "AA"],
+        "N320": ["WX", "HG", "XG", "XQ", "AQ", "AA"],
+        "X310": ["1G", "HG", "XG", "HA", "XA"],
+        "X300": ["1G", "HG", "XG", "HA", "XA"],
+        "X410": [""],
+        "X440": [""],
+    }
+    targets = []
+    for target, fpgas in target_fpga_map.items():
+        for fpga in fpgas:
+            if fpga:
+                targets.append(f"{target}_{fpga}")
+            else:
+                targets.append(target)
+    return targets
+
+
 def setup_parser():
     """Create argument parser."""
     parser = argparse.ArgumentParser(
@@ -42,7 +66,7 @@ def setup_parser():
         "-B",
         "--build-dir",
         help="Path to directory where the image core and and build artifacts will be generated. "
-        "Defaults to \"build-<image-core-name>\" in the base directory.",
+        'Defaults to "build-<image-core-name>" in the base directory.',
         required=False,
         default=None,
     )
@@ -50,7 +74,7 @@ def setup_parser():
         "-O",
         "--build-output-dir",
         help="Path to directory for final FPGA build outputs. "
-        "Defaults to \"build\" in the base directory.",
+        'Defaults to "build" in the base directory.',
         required=False,
         default=None,
     )
@@ -58,7 +82,7 @@ def setup_parser():
         "-E",
         "--build-ip-dir",
         help="Path to directory for IP build artifacts. "
-        "Defaults to \"build-ip\" in the base directory.",
+        'Defaults to "build-ip" in the base directory.',
         required=False,
         default=None,
     )
@@ -132,6 +156,7 @@ def setup_parser():
         "--target",
         help="Build target (e.g. X310_HG, N320_XG, ...). Needs to be specified "
         "either here, on the configuration file.",
+        choices=get_valid_targets(),
         default=None,
     )
     parser.add_argument(
@@ -194,16 +219,6 @@ def setup_parser():
     return parser
 
 
-def resolve_path(path, local):
-    """Replace path by local if path is enclosed with "@" (placeholder markers).
-
-    :param path: the path to check
-    :param local: new path content if path is placeholder
-    :return: path if path is not a placeholder else local
-    """
-    return re.sub("^@.*@$", local, path)
-
-
 def get_fpga_path(args):
     """Return FPGA path.
 
@@ -233,7 +248,12 @@ def get_fpga_path(args):
         if top_dir == "":
             fpga_path = None
             break
-    # If it's valid FPGA base path, use that
+    # Try to find an FPGA directory in the install prefix
+    if fpga_path is None and os.path.isdir(
+        os.path.join(get_pkg_data_path(), "rfnoc", "fpga", "usrp3")
+    ):
+        fpga_path = os.path.join(get_pkg_data_path(), "rfnoc", "fpga")
+    # If fpga_path is a valid FPGA base path, use it
     if fpga_path and os.path.isdir(os.path.join(fpga_path, "usrp3", "top")):
         logging.info("Using FPGA directory %s", fpga_path)
         return fpga_path
@@ -242,24 +262,6 @@ def get_fpga_path(args):
     sys.exit(1)
 
 
-def get_config_path():
-    """Return path that contains configurations files.
-
-    This is the main UHD installation path for package data (e.g., /usr/share/uhd).
-
-    Will return the directory path where the YAML configuration files are stored
-    (yml descriptions for block, IO signatures and device bsp, not the image
-    core files).
-
-    :return: Configuration path
-    """
-    return os.path.normpath(
-        resolve_path(
-            "@CONFIG_PATH@", os.path.join(os.path.dirname(__file__), "..", "include", "uhd")
-        )
-    )
-
-
 def main():
     """Run image_builder.build_image.
 
@@ -308,12 +310,11 @@ def main():
         image_core_name=args.image_core_name,
         target=args.target,
         # Provide all the paths
-        base_dir = args.base_dir,
+        base_dir=args.base_dir,
         build_dir=args.build_dir,
         build_output_dir=args.build_output_dir,
         build_ip_dir=args.build_ip_dir,
         repo_fpga_path=get_fpga_path(args),
-        config_path=get_config_path(),
         yaml_path=args.yaml_config if args.yaml_config else args.grc_config,
         include_paths=args.include_dir,
         vivado_path=args.vivado_path,
