@@ -9,11 +9,6 @@
 namespace py = pybind11;
 #define LIBMPM_PYTHON
 
-// Allow boost::shared_ptr<T> to be a holder class of an object (PyBind11
-// supports std::shared_ptr and std::unique_ptr out of the box)
-#include <boost/shared_ptr.hpp>
-PYBIND11_DECLARE_HOLDER_TYPE(T, boost::shared_ptr<T>);
-
 #include <mpm/ad9361/ad9361_ctrl.hpp>
 #include <mpm/dboards/neon_manager.hpp>
 #include <mpm/spi/spi_python.hpp>
